@@ -5,21 +5,21 @@
  * The debugging module provides a standard collection of
  * procedures for setting, examining, and testing debugging flags.
  *
- *     ********************************************************************* 
- *     * Copyright (C) 1985, 1990 Regents of the University of California. * 
- *     * Permission to use, copy, modify, and distribute this              * 
- *     * software and its documentation for any purpose and without        * 
- *     * fee is hereby granted, provided that the above copyright          * 
- *     * notice appear in all copies.  The University of California        * 
- *     * makes no representations about the suitability of this            * 
- *     * software for any purpose.  It is provided "as is" without         * 
- *     * express or implied warranty.  Export of this software outside     * 
- *     * of the United States of America may require an export license.    * 
+ *     *********************************************************************
+ *     * Copyright (C) 1985, 1990 Regents of the University of California. *
+ *     * Permission to use, copy, modify, and distribute this              *
+ *     * software and its documentation for any purpose and without        *
+ *     * fee is hereby granted, provided that the above copyright          *
+ *     * notice appear in all copies.  The University of California        *
+ *     * makes no representations about the suitability of this            *
+ *     * software for any purpose.  It is provided "as is" without         *
+ *     * express or implied warranty.  Export of this software outside     *
+ *     * of the United States of America may require an export license.    *
  *     *********************************************************************
  */
 
 #ifndef lint
-static char rcsid[] = "$Header: /ufs/repository/magic/debug/debugFlags.c,v 1.2 2001/01/12 22:12:26 jsolomon Exp $";
+static char rcsid[] __attribute__ ((unused)) = "$Header: /usr/cvsroot/magic-8.0/debug/debugFlags.c,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $";
 #endif  /* not lint */
 
 #include <stdio.h>
@@ -32,7 +32,7 @@ static char rcsid[] = "$Header: /ufs/repository/magic/debug/debugFlags.c,v 1.2 2
 struct debugClient debugClients[MAXDEBUGCLIENTS];
 int debugNumClients = 0;
 
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -84,7 +84,7 @@ DebugAddClient(name, maxflags)
 
     return ((ClientData) debugNumClients++);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -121,7 +121,7 @@ DebugAddFlag(clientID, name)
 
     if (id < 0 || id >= debugNumClients)
     {
-	TxError("DebugAddFlag: bad client id %d (flag %s)\n", clientID, name);
+	TxError("DebugAddFlag: bad client id %lu (flag %s)\n", clientID, name);
 	return (0);
     }
 
@@ -137,7 +137,7 @@ DebugAddFlag(clientID, name)
     dc->dc_flags[dc->dc_nflags].df_value = FALSE;
     return (dc->dc_nflags++);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -165,7 +165,7 @@ DebugShow(clientID)
 
     if (id < 0 || id >= debugNumClients)
     {
-	TxError("DebugShow: bad client id %d\n", clientID);
+	TxError("DebugShow: bad client id %lu\n", clientID);
 	return;
     }
     dc = &debugClients[id];
@@ -173,7 +173,7 @@ DebugShow(clientID)
 	TxPrintf("%-5.5s %s\n", dc->dc_flags[n].df_value ? "TRUE" : "FALSE",
 		dc->dc_flags[n].df_name);
 }
-
+
 /*
  * ----------------------------------------------------------------------------
  *
@@ -208,7 +208,7 @@ DebugSet(clientID, argc, argv, value)
 
     if (id < 0 || id >= debugNumClients)
     {
-	TxError("DebugSet: bad client id %d\n", clientID);
+	TxError("DebugSet: bad client id %lu\n", (unsigned long)clientID);
 	return;
     }
     dc = &debugClients[id];
