@@ -7,9 +7,7 @@
  */
 
 #include <stdio.h>
-#ifdef OS2
 #include <stdlib.h>
-#endif  /* OS2 */
 #include <X11/Xlib.h>
 
 #include "tcltk/tclmagic.h"
@@ -25,11 +23,10 @@
 #include "grTkCommon.h"
 #include "grTkInt.h"
 
-extern GrGlyphs *grCursorGlyphs;
 extern HashTable	grTkWindowTable;
 extern XColor colors[];
 
-
+
 /*
  * ----------------------------------------------------------------------------
  * GrTkDrawGlyph --
@@ -52,7 +49,7 @@ GrTkDrawGlyph (gl, p)
     Rect bBox;
     bool anyObscure;
     LinkedRect *ob;
-    
+
     GR_CHECK_LOCK();
     bBox.r_ll = *p;
     bBox.r_xtop = p->p_x + gl->gr_xsize - 1;
@@ -67,6 +64,8 @@ GrTkDrawGlyph (gl, p)
     }
     if(grDisplay.depth <= 8) {
       XSetPlaneMask(grXdpy, grGCGlyph, grPlanes[127]); }
+
+    XSetFillStyle(grXdpy, grGCGlyph, FillSolid);
     if ((!anyObscure) && (GEO_SURROUND(&grCurClip, &bBox)) ) {
 	int *pixelp, x, y;
 
@@ -78,10 +77,13 @@ GrTkDrawGlyph (gl, p)
 	    y1 = grMagicToX(bBox.r_ybot + y);
 	    for (x = 0; x < gl->gr_xsize; x++) {
 		int color;
-	        color = GrStyleTable[*pixelp++].color;
-		x1 = bBox.r_xbot + x;
-		XSetForeground(grXdpy, grGCGlyph, grPixels[color]);
-		XDrawPoint(grXdpy, grCurrent.windowid, grGCGlyph, x1, y1);
+		if (*pixelp != 0) {
+		    color = GrStyleTable[*pixelp].color;
+		    x1 = bBox.r_xbot + x;
+		    XSetForeground(grXdpy, grGCGlyph, grPixels[color]);
+		    XDrawPoint(grXdpy, grCurrent.windowid, grGCGlyph, x1, y1);
+		}
+		pixelp++;
 	    }
 	}
     } else {
@@ -94,7 +96,7 @@ GrTkDrawGlyph (gl, p)
 	    if ( (yloc <= grCurClip.r_ytop) && (yloc >= grCurClip.r_ybot) ) {
 		int laststartx;
 		laststartx = bBox.r_xbot - 1;
-		for (startx = bBox.r_xbot; startx <= bBox.r_xtop; 
+		for (startx = bBox.r_xbot; startx <= bBox.r_xtop;
 			startx = endx + 1) {
 		    int *pixelp;
 
@@ -103,7 +105,7 @@ GrTkDrawGlyph (gl, p)
 
 		    if (anyObscure) {
 			for (ob = grCurObscure; ob != NULL; ob = ob->r_next) {
-			    if ( (ob->r_r.r_ybot <= yloc) && 
+			    if ( (ob->r_r.r_ybot <= yloc) &&
 				 (ob->r_r.r_ytop >= yloc) ) {
 				if (ob->r_r.r_xbot <= startx)
 				    startx = MAX(startx, ob->r_r.r_xtop + 1);
@@ -114,7 +116,7 @@ GrTkDrawGlyph (gl, p)
 		    }
 
 		    /* stop if we aren't advancing */
-		    if (startx == laststartx) break;  
+		    if (startx == laststartx) break;
 		    laststartx = startx;
 		    if (startx > endx) continue;
 
@@ -123,10 +125,13 @@ GrTkDrawGlyph (gl, p)
 			    (startx - bBox.r_xbot)]);
 		    for ( ; startx <= endx; startx++) {
 			int color;
-			color = GrStyleTable[*pixelp++].color;
-			XSetForeground(grXdpy, grGCGlyph, grPixels[color]);
-			XDrawPoint(grXdpy, grCurrent.windowid, grGCGlyph,
-				  startx, grMagicToX(yloc));
+			if (*pixelp != 0) {
+			    color = GrStyleTable[*pixelp].color;
+			    XSetForeground(grXdpy, grGCGlyph, grPixels[color]);
+			    XDrawPoint(grXdpy, grCurrent.windowid, grGCGlyph,
+					startx, grMagicToX(yloc));
+			}
+			pixelp++;
 		    }
 		    startx = endx + 1;
 		}
@@ -136,7 +141,7 @@ GrTkDrawGlyph (gl, p)
     }
 }
 
-
+
 /*
  * ----------------------------------------------------------------------------
  * GrTkSetCursor:
@@ -161,10 +166,15 @@ GrTkSetCursor(cursorNum)
     HashSearch	hs;
     Tk_Window	tkwind;
 
+    if (cursorNum >= MAX_CURSORS)
+    {
+	TxError("No such cursor!\n");
+	return;
+    }
     grCurrent.cursor = grCursors[cursorNum];
-    
+
     HashStartSearch(&hs);
-    while (entry = HashNext(&grTkWindowTable,&hs))
+    while ((entry = HashNext(&grTkWindowTable,&hs)))
     {
     	if (HashGetValue(entry))
 	{
