@@ -3,21 +3,21 @@
  *
  * Internal definitions for the plow module.
  *
- *     ********************************************************************* 
- *     * Copyright (C) 1985, 1990 Regents of the University of California. * 
- *     * Permission to use, copy, modify, and distribute this              * 
- *     * software and its documentation for any purpose and without        * 
- *     * fee is hereby granted, provided that the above copyright          * 
- *     * notice appear in all copies.  The University of California        * 
- *     * makes no representations about the suitability of this            * 
- *     * software for any purpose.  It is provided "as is" without         * 
- *     * express or implied warranty.  Export of this software outside     * 
- *     * of the United States of America may require an export license.    * 
+ *     *********************************************************************
+ *     * Copyright (C) 1985, 1990 Regents of the University of California. *
+ *     * Permission to use, copy, modify, and distribute this              *
+ *     * software and its documentation for any purpose and without        *
+ *     * fee is hereby granted, provided that the above copyright          *
+ *     * notice appear in all copies.  The University of California        *
+ *     * makes no representations about the suitability of this            *
+ *     * software for any purpose.  It is provided "as is" without         *
+ *     * express or implied warranty.  Export of this software outside     *
+ *     * of the United States of America may require an export license.    *
  *     *********************************************************************
  *
  * Needs to include: magic.h, geometry.h, tile.h
  *
- * rcsid $Header: /usr/cvsroot/magic-7.5/plow/plowInt.h,v 1.1.1.1 2006/04/10 22:03:13 tim Exp $
+ * rcsid $Header: /usr/cvsroot/magic-8.0/plow/plowInt.h,v 1.1.1.1 2008/02/03 20:43:50 tim Exp $
  */
 
 #ifndef _PLOWINT_H
@@ -160,9 +160,9 @@ typedef struct
  * stored explicitly; the leading coordinate is the trailing coordinate
  * of the tile to its right.
  */
-#define	TRAIL_UNINIT	MINFINITY
-#define	TRAILING(tp)	(( ((int) (tp)->ti_client) == TRAIL_UNINIT) \
-				? LEFT(tp) : ((int) (tp)->ti_client))
+#define	TRAIL_UNINIT	CLIENTDEFAULT
+#define	TRAILING(tp)	(((tp)->ti_client == (ClientData)TRAIL_UNINIT) \
+				? LEFT(tp) : ((int)(tp)->ti_client))
 #define	LEADING(tp)	TRAILING(TR(tp))
 
 #define	plowSetTrailing(tp, n)	((tp)->ti_client = (ClientData) (n))
@@ -186,6 +186,7 @@ typedef struct prule
     int			 pr_dist;	/* Distance associated with this
 					 * design rule.
 					 */
+    int			 pr_mod;	/* Modulus for pr_dist	*/
     short		 pr_pNum;	/* Plane on which to apply rule
 					 * (for spacing rules only).
 					 */
@@ -246,6 +247,43 @@ extern bool plowQueueLeftmost();
 extern bool plowQueueRightmost();
 extern Tile *plowSplitY();
 
+/* C99 compat */
+extern bool Plow();
+extern void PlowClearBound();
+extern bool PlowSelection();
+extern void PlowSetBound();
+extern void PlowStraighten();
+extern int  plowApplySearchRules();
+extern int  plowAtomize();
+extern void plowCleanupJogs();
+extern void plowDebugEdge();
+extern int  plowFindWidth();
+extern int  plowFindWidthBack();
+extern int  plowGenRandom();
+extern void plowQueueDone();
+extern void plowQueueInit();
+extern int  plowSrFinalArea();
+extern void plowSrOutline();
+extern int  plowSrShadow();
+extern int  plowSrShadowBack();
+extern int  plowSrShadowInitial();
+extern bool plowYankMore();
+extern void PlowRandomTest();
+extern void plowDebugInit();
+extern void plowMergeBottom();
+extern void plowMergeTop();
+extern void plowMoveEdge();
+extern int  plowShadowInitialRHS();
+extern int  plowShadowLHS();
+extern int  plowShadowRHS();
+extern void plowTechShow();
+extern void plowUpdateLabels();
+extern void plowYankCreate();
+
+#ifndef NO_RUSAGE
+extern void plowShowTime();
+#endif
+
 /* ------------------------- Debugging flags -------------------------- */
 
 /*
